@@ -3,10 +3,10 @@
 /*----------------------------------------------------------------------
 -- This file is a part of the MARST package.
 --
--- Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                    Department for Applied Informatics,
---                    Moscow Aviation Institute, Moscow, Russia.
---                    All rights reserved.
+-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--                          Department for Applied Informatics,
+--                          Moscow Aviation Institute, Moscow, Russia.
+--                          All rights reserved.
 --
 -- This code is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -178,8 +178,8 @@ double set_real(struct desc x, double val)
 {     /* assigns value to real formal parameter called by name */
       if (!x.lval)
          fault("assignment to a real formal parameter called by name no"
-            "t possible because final actual parameter is not variable")
-            ;
+            "t possible because final actual parameter is not a variabl"
+            "e");
       switch (x.type)
       {  case 'r':
             *x.u.real_ptr = val;
@@ -201,8 +201,8 @@ int set_int(struct desc x, int val)
 {     /* assigns value to integer formal parameter called by name */
       if (!x.lval)
          fault("assignment to an integer formal parameter called by nam"
-            "e not possible because final actual parameter is not varia"
-            "ble");
+            "e not possible because final actual parameter is not a var"
+            "iable");
       switch (x.type)
       {  case 'r':
             *x.u.real_ptr = int2real(val);
@@ -224,8 +224,8 @@ bool set_bool(struct desc x, bool val)
 {     /* assigns value to Boolean formal parameter called by name */
       if (!x.lval)
          fault("assignment to a Boolean formal parameter called by name"
-            " not possible because final actual parameter is not variab"
-            "le");
+            " not possible because final actual parameter is not a vari"
+            "able");
       switch (x.type)
       {  case 'b':
             *x.u.bool_ptr = val;
