@@ -3,10 +3,10 @@
 /*----------------------------------------------------------------------
 -- This file is a part of the MARST package.
 --
--- Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                    Department for Applied Informatics,
---                    Moscow Aviation Institute, Moscow, Russia.
---                    All rights reserved.
+-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--                          Department for Applied Informatics,
+--                          Moscow Aviation Institute, Moscow, Russia.
+--                          All rights reserved.
 --
 -- This code is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 
 /*--------------------------------------------------------------------*/
 
-static char *version = "MACVT -- Algol 60 Converter, Version 2.1";
+static char *version = "MACVT -- Algol 60 Converter, Version 2.2";
 /* Version information. */
 
 static char *infilename = "";
@@ -961,8 +961,8 @@ static void display_help(char *my_name)
 
 static void display_version(void)
 {     printf("%s\n", version);
-      printf("Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>, M"
-         "osc.Av.Inst.\n");
+      printf("Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet."
+         "ru, mao@gnu.org>\n");
       printf("This program is free software; you may redistribute it un"
          "der the terms of\n");
       printf("the GNU General Public License. This program has absolute"
